<?php

namespace Drupal\asps_tag_management\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure ASPS Tag Management settings for this site.
 *
 * @internal
 */
class ASPSTagSettings extends ConfigFormBase {

  /**
   * Constructs a ASPS Tag Management settings object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    parent::__construct($config_factory);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['asps_tag_management.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'asps_tag_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    \Drupal::messenger()->deleteAll();
    if (asps_tag_management_is_debug_mode()) {
      \Drupal::messenger()->addMessage($this->t('Debug mode is enabled. Please disable it to make this module work. Visit <a href="@page" target="_blank">page</a> for more information on disabling Debug mode.', ['@page' => 'https://www.drupal.org/docs/8/theming/twig/debugging-twig-templates']), MessengerInterface::TYPE_ERROR);
    }

    $settings = $this->config('asps_tag_management.settings');

    $mode_default_value = $settings->get('mode') ? $settings->get('mode') : 0;

    if ($mode_default_value) {
      \Drupal::messenger()->addMessage($this->t('This plugin is currently active. Please clear Drupal <a href="@pcache" target="_blank">Cache</a>, if changes are not reflected.', ['@pcache' => Url::fromUserInput('/admin/config/development/performance')]), MessengerInterface::TYPE_STATUS);
    }
    else {
      \Drupal::messenger()->addMessage($this->t('This plugin is currently disabled. No tags will be inserted.'), MessengerInterface::TYPE_ERROR);
    }

    $form['mode'] = array(
      '#type' => 'radios',
      '#title' => $this
        ->t('Mode'),
      '#default_value' => $mode_default_value,
      '#options' => array(
        1 => $this->t('Active'),
        0 => $this->t('Disabled'),
        2 => $this->t('Debug')
      ),
    );

    $form['admin_pages'] = array(
      '#type' => 'checkbox',
      '#default_value' => !empty($settings->get('admin_pages')) ? $settings->get('admin_pages') : '',
      '#title' => t('Exempt Admin from ASPS tags?'),
    );

    $form['url_keywords'] = array(
      '#type' => 'fieldset',
      '#title' => $this->t('URL Keyword Triggers'),
    );

    $form['url_keywords']['keywords'] = array(
      '#type' => 'textarea',
      '#title' => $this->t('Keywords'),
      '#description' => $this->t('Separated by Commas e.g. lesson,course,download'),
      '#default_value' => !empty($settings->get('keywords')) ? $settings->get('keywords') : '',
    );

    $enforce_asps = $settings->get('enforce_asps') ? $settings->get('enforce_asps') : 0;

    $form['url_keywords']['enforce_asps'] = array(
      '#type' => 'radios',
      '#title' => $this
        ->t('Enforce ASPS'),
      '#default_value' => $enforce_asps,
      '#options' => array(
        0 => $this->t('To all in the above list'),
        1 => $this->t('To all except in the above list'),
      ),
    );

    $form['options_to_allow'] = array(
      '#type' => 'fieldset',
      '#title' => $this->t('Select Options to Allow'),
    );

    $form['options_to_allow']['allow_capture'] = array(
      '#type' => 'checkbox',
      '#default_value' => !empty($settings->get('allow_capture')) ? $settings->get('allow_capture') : 0,
      '#title' => t('Allow Capture'),
    );

    $form['options_to_allow']['allow_keyboard'] = array(
      '#type' => 'checkbox',
      '#default_value' => !empty($settings->get('allow_keyboard')) ? $settings->get('allow_keyboard') : 0,
      '#title' => t('Allow Keyboard'),
    );

    $form['options_to_allow']['allow_save'] = array(
      '#type' => 'checkbox',
      '#default_value' => !empty($settings->get('allow_save')) ? $settings->get('allow_save') : 0,
      '#title' => t('Allow Save'),
    );

    $form['options_to_allow']['allow_remote'] = array(
      '#type' => 'checkbox',
      '#default_value' => !empty($settings->get('allow_remote')) ? $settings->get('allow_remote') : 0,
      '#title' => t('Allow Remote'),
    );

    $form['options_to_allow']['allow_print'] = array(
      '#type' => 'checkbox',
      '#default_value' => !empty($settings->get('allow_print')) ? $settings->get('allow_print') : 0,
      '#title' => t('Allow Print'),
    );
	
	 $form['options_to_allow']['allow_mac'] = array(
      '#type' => 'checkbox',
      '#default_value' => !empty($settings->get('allow_mac')) ? $settings->get('allow_mac') : 0,
      '#title' => t('Allow Mac OSX'),
    );
	
	$form['options_to_allow']['allow_android'] = array(
      '#type' => 'checkbox',
      '#default_value' => !empty($settings->get('allow_android')) ? $settings->get('allow_android') : 0,
      '#title' => t('Allow Android'),
    );
	
	$form['options_to_allow']['allow_ios'] = array(
      '#type' => 'checkbox',
      '#default_value' => !empty($settings->get('allow_ios')) ? $settings->get('allow_ios') : 0,
      '#title' => t('Allow iOS'),
    );

    $form['browser_window'] = array(
      '#type' => 'fieldset',
      '#title' => $this->t('Browser Window'),
    );

    $form['browser_window']['height'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Height (in px)'),
	  '#size'  => 30,
      '#default_value' => !empty($settings->get('height')) ? $settings->get('height') : '',
    );

    $form['browser_window']['width'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Width (in px)'),
	  '#size'  => 30,
      '#default_value' => !empty($settings->get('width')) ? $settings->get('width') : '',
    );

    $form['browser_window']['kiosk_mode'] = array(
      '#type' => 'checkbox',
      '#default_value' => !empty($settings->get('kiosk_mode')) ? $settings->get('kiosk_mode') : '',
      '#title' => $this->t('Kiosk Mode'),
      '#description' => $this->t('Height and Width are not applicable if Kiosk mode is selected.')
    );

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('asps_tag_management.settings')
      ->set('mode', $form_state->getValue('mode'))
      ->set('admin_pages', $form_state->getValue('admin_pages'))
      ->set('keywords', $form_state->getValue('keywords'))
      ->set('enforce_asps', $form_state->getValue('enforce_asps'))
      ->set('allow_capture', $form_state->getValue('allow_capture'))
      ->set('allow_keyboard', $form_state->getValue('allow_keyboard'))
      ->set('allow_save', $form_state->getValue('allow_save'))
      ->set('allow_remote', $form_state->getValue('allow_remote'))
      ->set('allow_print', $form_state->getValue('allow_print'))
	  ->set('allow_mac', $form_state->getValue('allow_mac'))
	  ->set('allow_android', $form_state->getValue('allow_android'))
	  ->set('allow_ios', $form_state->getValue('allow_ios'))
      ->set('height', $form_state->getValue('height'))
      ->set('width', $form_state->getValue('width'))
      ->set('kiosk_mode', $form_state->getValue('kiosk_mode'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
